#ifndef HTTPFETCH_H
#define HTTPFETCH_H

#include <time.h>

#define MAX_DATETIME_LEN 256

#define HF_ERROR (-1)
#define HF_NOT_MODIFIED (-2)

int httpfetch(const char* strURI, char** buff, time_t tmModified, time_t* ptmRetModified);

#endif
